Project

Struct Project 

pub struct Project<Vocab: ActivityVocabulary = VocabularyTypes> { /* private fields */ }
Represents a project, a planned endeavor that involves usage of tools related to the software development lifecycle.

It may be a software project, but may also be totally unrelated to software development.

For example, it may be a book that is being written using Markdown files kept in a Git repository.

A Project object is a way to collect forge related components together under one title.

Example

use activityforge::{Project, context};
use activitystreams_vocabulary::{
    Collection, Iri, MultibaseHeader, MultibasePublicKey, Multikey, MultikeyPublicKey, Name,
};

let id = Iri::try_from("https://dev.example/projects/wanderer").unwrap();
let name = Name::try_from("Wanderer").unwrap();
let summary = "3D nature exploration game";
let inbox = Iri::try_from("https://dev.example/projects/wanderer/inbox").unwrap();
let outbox = Iri::try_from("https://dev.example/projects/wanderer/outbox").unwrap();
let followers = Iri::try_from("https://dev.example/projects/wanderer/followers").unwrap();

let key_id = Iri::try_from("https://dev.example/aviva/treesim#main-key").unwrap();
let controller = Iri::try_from("https://dev.example/aviva/treesim").unwrap();
let encoded_multibase = "u7QGwDY2Tjn93PVFWWq02piP1NE9_XRlg-c8-jhJiHqKBHw";

let item0 = Iri::try_from("https://dev.example/repos/opengl-vegetation").unwrap();
let item1 = Iri::try_from("https://dev.example/repos/opengl-vegetation/patch-tracker").unwrap();
let item2 = Iri::try_from("https://dev.example/repos/treesim").unwrap();
let item3 = Iri::try_from("https://dev.example/repos/treesim/patch-tracker").unwrap();
let item4 = Iri::try_from("https://dev.example/repos/wanderer").unwrap();
let item5 = Iri::try_from("https://dev.example/repos/wanderer/patch-tracker").unwrap();
let item6 = Iri::try_from("https://dev.example/issue-trackers/wanderer").unwrap();

let json_str = format!(
r#"{{
  "@context": [
    "https://www.w3.org/ns/activitystreams",
    "https://forgefed.org/ns"
  ],
  "type": "Project",
  "id": "{id}",
  "name": "{name}",
  "summary": "{summary}",
  "inbox": "{inbox}",
  "outbox": "{outbox}",
  "followers": "{followers}",
  "assertionMethod": [
    {{
      "type": "Multikey",
      "id": "{key_id}",
      "controller": "{controller}",
      "publicKeyMultibase": "{encoded_multibase}"
    }}
  ],
  "components": {{
    "type": "Collection",
    "totalItems": 7,
    "items": [
      "{item0}",
      "{item1}",
      "{item2}",
      "{item3}",
      "{item4}",
      "{item5}",
      "{item6}"
    ]
  }}
}}"#
        );

let context = context::forgefed_context();

let multibase = MultibasePublicKey::new()
    .with_header(MultibaseHeader::Base64UrlNoPad)
    .with_key(MultikeyPublicKey::Ed25519([
        0xb0, 0x0d, 0x8d, 0x93, 0x8e, 0x7f, 0x77, 0x3d, 0x51, 0x56, 0x5a, 0xad, 0x36, 0xa6,
        0x23, 0xf5, 0x34, 0x4f, 0x7f, 0x5d, 0x19, 0x60, 0xf9, 0xcf, 0x3e, 0x8e, 0x12, 0x62,
        0x1e, 0xa2, 0x81, 0x1f,
    ]));

let multikey = Multikey::new_inner()
    .with_id(key_id)
    .with_controller(controller.clone())
    .with_public_key_multibase(multibase);

let items = [item0, item1, item2, item3, item4, item5, item6];
let components = Collection::new_inner()
    .with_total_items(items.len() as u64)
    .with_items(items);

let repository = Project::new()
    .with_context_property(context)
    .with_id(id)
    .with_name(name)
    .with_summary(summary)
    .with_inbox(inbox)
    .with_outbox(outbox)
    .with_followers(followers)
    .with_assertion_method([multikey])
    .with_components(components);

assert_eq!(serde_json::to_string_pretty(&repository).unwrap(), json_str);
assert_eq!(
    serde_json::from_str::<Project>(json_str.as_str()).unwrap(),
    repository
);

Implementations

Source

impl<Vocab: ActivityVocabulary + From<ActorType>> Project<Vocab>

pub fn new() -> Self

Creates a new Project.

pub fn new_inner() -> Self

Creates a new Project for use as an inner member of another object.

Encodes the type without the @context field.

pub fn new_kind(kind: Vocab) -> Self

Creates a new Project.

pub fn without_context_property(self) -> Self

Builder function that unsets the @context field.

Source

impl<Vocab: ActivityVocabulary> Project<Vocab>

pub fn kind(&self) -> &Vocab

Gets the Project kind.

Provides the ActivityStream Vocabulary type.

pub fn set_kind<I: Into<Vocab>>(&mut self, val: I)

Sets the Project kind.

Provides the ActivityStream Vocabulary type.

pub fn with_kind<I: Into<Vocab>>(self, val: I) -> Self

Builder function that sets the Project kind.

Provides the ActivityStream Vocabulary type.

Source

impl<Vocab: ActivityVocabulary> Project<Vocab>

pub fn id(&self) -> Option<&Iri>

Gets the Project id.

Provides the globally unique identifier for an Object.

pub fn set_id<I: Into<Iri>>(&mut self, val: I)

Sets the Project id.

Provides the globally unique identifier for an Object.

pub fn unset_id(&mut self) -> Option<Iri>

Unsets the Project id.

Provides the globally unique identifier for an Object.

pub fn with_id<I: Into<Iri>>(self, val: I) -> Self

Builder function that sets the Project id.

Provides the globally unique identifier for an Object.

pub fn context_property(&self) -> Option<&Context>

Gets the Project context_property.

Represents the special @context property to define the processing context.

The value of the @context property is defined by the JSON-LD specification.

pub fn set_context_property<I: Into<Context>>(&mut self, val: I)

Sets the Project context_property.

Represents the special @context property to define the processing context.

The value of the @context property is defined by the JSON-LD specification.

pub fn unset_context_property(&mut self) -> Option<Context>

Unsets the Project context_property.

Represents the special @context property to define the processing context.

The value of the @context property is defined by the JSON-LD specification.

pub fn with_context_property<I: Into<Context>>(self, val: I) -> Self

Builder function that sets the Project context_property.

Represents the special @context property to define the processing context.

The value of the @context property is defined by the JSON-LD specification.

pub fn name(&self) -> Option<&Name>

Gets the Project name.

A simple, human-readable, plain-text name for the object.

HTML markup MUST NOT be included.

The name MAY be expressed using multiple language-tagged values.

pub fn set_name<I: Into<Name>>(&mut self, val: I)

Sets the Project name.

A simple, human-readable, plain-text name for the object.

HTML markup MUST NOT be included.

The name MAY be expressed using multiple language-tagged values.

pub fn unset_name(&mut self) -> Option<Name>

Unsets the Project name.

A simple, human-readable, plain-text name for the object.

HTML markup MUST NOT be included.

The name MAY be expressed using multiple language-tagged values.

pub fn with_name<I: Into<Name>>(self, val: I) -> Self

Builder function that sets the Project name.

A simple, human-readable, plain-text name for the object.

HTML markup MUST NOT be included.

The name MAY be expressed using multiple language-tagged values.

pub fn name_map(&self) -> Option<&NameMap>

Gets the Project name_map.

A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.

HTML markup MUST NOT be included.

pub fn set_name_map<I: Into<NameMap>>(&mut self, val: I)

Sets the Project name_map.

A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.

HTML markup MUST NOT be included.

pub fn unset_name_map(&mut self) -> Option<NameMap>

Unsets the Project name_map.

A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.

HTML markup MUST NOT be included.

pub fn with_name_map<I: Into<NameMap>>(self, val: I) -> Self

Builder function that sets the Project name_map.

A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.

HTML markup MUST NOT be included.

pub fn content_map(&self) -> Option<&LanguageMap>

Gets the Project content_map.

The content or textual representation of the Object encoded as a JSON string, expressed using multiple language-tagged values.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

pub fn set_content_map<I: Into<LanguageMap>>(&mut self, val: I)

Sets the Project content_map.

The content or textual representation of the Object encoded as a JSON string, expressed using multiple language-tagged values.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

pub fn unset_content_map(&mut self) -> Option<LanguageMap>

Unsets the Project content_map.

The content or textual representation of the Object encoded as a JSON string, expressed using multiple language-tagged values.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

pub fn with_content_map<I: Into<LanguageMap>>(self, val: I) -> Self

Builder function that sets the Project content_map.

The content or textual representation of the Object encoded as a JSON string, expressed using multiple language-tagged values.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

pub fn summary_map(&self) -> Option<&LanguageMap>

Gets the Project summary_map.

A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.

pub fn set_summary_map<I: Into<LanguageMap>>(&mut self, val: I)

Sets the Project summary_map.

A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.

pub fn unset_summary_map(&mut self) -> Option<LanguageMap>

Unsets the Project summary_map.

A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.

pub fn with_summary_map<I: Into<LanguageMap>>(self, val: I) -> Self

Builder function that sets the Project summary_map.

A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.

pub fn duration(&self) -> Option<&Duration>

Gets the Project duration.

When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.

The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.

pub fn set_duration<I: Into<Duration>>(&mut self, val: I)

Sets the Project duration.

When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.

The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.

pub fn unset_duration(&mut self) -> Option<Duration>

Unsets the Project duration.

When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.

The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.

pub fn with_duration<I: Into<Duration>>(self, val: I) -> Self

Builder function that sets the Project duration.

When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.

The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.

pub fn source(&self) -> Option<&ContentItem>

Gets the Project source.

Represents the source of the content field.

pub fn set_source<I: Into<ContentItem>>(&mut self, val: I)

Sets the Project source.

Represents the source of the content field.

pub fn unset_source(&mut self) -> Option<ContentItem>

Unsets the Project source.

Represents the source of the content field.

pub fn with_source<I: Into<ContentItem>>(self, val: I) -> Self

Builder function that sets the Project source.

Represents the source of the content field.

pub fn proof(&self) -> Option<&DataIntegrityProof>

Gets the Project proof.

Represents a DataIntegrityProof.

pub fn set_proof<I: Into<DataIntegrityProof>>(&mut self, val: I)

Sets the Project proof.

Represents a DataIntegrityProof.

pub fn unset_proof(&mut self) -> Option<DataIntegrityProof>

Unsets the Project proof.

Represents a DataIntegrityProof.

pub fn with_proof<I: Into<DataIntegrityProof>>(self, val: I) -> Self

Builder function that sets the Project proof.

Represents a DataIntegrityProof.

pub fn url(&self) -> Option<&LinkItems>

Gets the Project url.

Identifies one or more links to representations of the object

pub fn set_url<I: Into<LinkItems>>(&mut self, val: I)

Sets the Project url.

Identifies one or more links to representations of the object

pub fn unset_url(&mut self) -> Option<LinkItems>

Unsets the Project url.

Identifies one or more links to representations of the object

pub fn with_url<I: Into<LinkItems>>(self, val: I) -> Self

Builder function that sets the Project url.

Identifies one or more links to representations of the object

Source

impl<Vocab: ActivityVocabulary> Project<Vocab>

pub fn content(&self) -> Option<&str>

Gets the Project content.

The content or textual representation of the Object encoded as a JSON string.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

The content MAY be expressed using multiple language-tagged values.

pub fn set_content<I: Into<String>>(&mut self, val: I)

Sets the Project content.

The content or textual representation of the Object encoded as a JSON string.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

The content MAY be expressed using multiple language-tagged values.

pub fn unset_content(&mut self) -> Option<String>

Unsets the Project content.

The content or textual representation of the Object encoded as a JSON string.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

The content MAY be expressed using multiple language-tagged values.

pub fn with_content<I: Into<String>>(self, val: I) -> Self

Builder function that sets the Project content.

The content or textual representation of the Object encoded as a JSON string.

By default, the value of content is HTML.

The mediaType property can be used in the object to indicate a different content type.

The content MAY be expressed using multiple language-tagged values.

pub fn summary(&self) -> Option<&str>

Gets the Project summary.

A natural language summarization of the object encoded as HTML.

Multiple language tagged summaries MAY be provided.

pub fn set_summary<I: Into<String>>(&mut self, val: I)

Sets the Project summary.

A natural language summarization of the object encoded as HTML.

Multiple language tagged summaries MAY be provided.

pub fn unset_summary(&mut self) -> Option<String>

Unsets the Project summary.

A natural language summarization of the object encoded as HTML.

Multiple language tagged summaries MAY be provided.

pub fn with_summary<I: Into<String>>(self, val: I) -> Self

Builder function that sets the Project summary.

A natural language summarization of the object encoded as HTML.

Multiple language tagged summaries MAY be provided.

Source

impl<Vocab: ActivityVocabulary> Project<Vocab>

pub fn attachment(&self) -> Option<&Items>

Gets the Project attachment.

Identifies a resource attached or related to an object that potentially requires special handling.

The intent is to provide a model that is at least semantically similar to attachments in email.

pub fn set_attachment<I: Into<Items>>(&mut self, val: I)

Sets the Project attachment.

Identifies a resource attached or related to an object that potentially requires special handling.

The intent is to provide a model that is at least semantically similar to attachments in email.

pub fn unset_attachment(&mut self) -> Option<Box<Items>>

Unsets the Project attachment.

Identifies a resource attached or related to an object that potentially requires special handling.

The intent is to provide a model that is at least semantically similar to attachments in email.

pub fn with_attachment<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project attachment.

Identifies a resource attached or related to an object that potentially requires special handling.

The intent is to provide a model that is at least semantically similar to attachments in email.

pub fn attributed_to(&self) -> Option<&Item>

Gets the Project attributed_to.

Identifies one or more entities to which this object is attributed.

The attributed entities might not be Actors.

For instance, an object might be attributed to the completion of another activity.

pub fn set_attributed_to<I: Into<Item>>(&mut self, val: I)

Sets the Project attributed_to.

Identifies one or more entities to which this object is attributed.

The attributed entities might not be Actors.

For instance, an object might be attributed to the completion of another activity.

pub fn unset_attributed_to(&mut self) -> Option<Box<Item>>

Unsets the Project attributed_to.

Identifies one or more entities to which this object is attributed.

The attributed entities might not be Actors.

For instance, an object might be attributed to the completion of another activity.

pub fn with_attributed_to<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project attributed_to.

Identifies one or more entities to which this object is attributed.

The attributed entities might not be Actors.

For instance, an object might be attributed to the completion of another activity.

pub fn audience(&self) -> Option<&Item>

Gets the Project audience.

Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.

pub fn set_audience<I: Into<Item>>(&mut self, val: I)

Sets the Project audience.

Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.

pub fn unset_audience(&mut self) -> Option<Box<Item>>

Unsets the Project audience.

Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.

pub fn with_audience<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project audience.

Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.

pub fn context(&self) -> Option<&Item>

Gets the Project context.

Identifies the context within which the object exists or an activity was performed.

The notion of “context” used is intentionally vague.

The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.

An example could be all activities relating to a common project or event.

pub fn set_context<I: Into<Item>>(&mut self, val: I)

Sets the Project context.

Identifies the context within which the object exists or an activity was performed.

The notion of “context” used is intentionally vague.

The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.

An example could be all activities relating to a common project or event.

pub fn unset_context(&mut self) -> Option<Box<Item>>

Unsets the Project context.

Identifies the context within which the object exists or an activity was performed.

The notion of “context” used is intentionally vague.

The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.

An example could be all activities relating to a common project or event.

pub fn with_context<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project context.

Identifies the context within which the object exists or an activity was performed.

The notion of “context” used is intentionally vague.

The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.

An example could be all activities relating to a common project or event.

pub fn generator(&self) -> Option<&Item>

Gets the Project generator.

Identifies the entity (e.g. an application) that generated the object.

pub fn set_generator<I: Into<Item>>(&mut self, val: I)

Sets the Project generator.

Identifies the entity (e.g. an application) that generated the object.

pub fn unset_generator(&mut self) -> Option<Box<Item>>

Unsets the Project generator.

Identifies the entity (e.g. an application) that generated the object.

pub fn with_generator<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project generator.

Identifies the entity (e.g. an application) that generated the object.

pub fn icon(&self) -> Option<&ImageItem>

Gets the Project icon.

Indicates an entity that describes an icon for this object.

The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.

pub fn set_icon<I: Into<ImageItem>>(&mut self, val: I)

Sets the Project icon.

Indicates an entity that describes an icon for this object.

The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.

pub fn unset_icon(&mut self) -> Option<Box<ImageItem>>

Unsets the Project icon.

Indicates an entity that describes an icon for this object.

The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.

pub fn with_icon<I: Into<ImageItem>>(self, val: I) -> Self

Builder function that sets the Project icon.

Indicates an entity that describes an icon for this object.

The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.

pub fn image(&self) -> Option<&ImageItem>

Gets the Project image.

Indicates an entity that describes an image for this object.

Unlike the icon property, there are no aspect ratio or display size limitations assumed.

pub fn set_image<I: Into<ImageItem>>(&mut self, val: I)

Sets the Project image.

Indicates an entity that describes an image for this object.

Unlike the icon property, there are no aspect ratio or display size limitations assumed.

pub fn unset_image(&mut self) -> Option<Box<ImageItem>>

Unsets the Project image.

Indicates an entity that describes an image for this object.

Unlike the icon property, there are no aspect ratio or display size limitations assumed.

pub fn with_image<I: Into<ImageItem>>(self, val: I) -> Self

Builder function that sets the Project image.

Indicates an entity that describes an image for this object.

Unlike the icon property, there are no aspect ratio or display size limitations assumed.

pub fn in_reply_to(&self) -> Option<&Item>

Gets the Project in_reply_to.

Indicates one or more entities for which this object is considered a response.

pub fn set_in_reply_to<I: Into<Item>>(&mut self, val: I)

Sets the Project in_reply_to.

Indicates one or more entities for which this object is considered a response.

pub fn unset_in_reply_to(&mut self) -> Option<Box<Item>>

Unsets the Project in_reply_to.

Indicates one or more entities for which this object is considered a response.

pub fn with_in_reply_to<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project in_reply_to.

Indicates one or more entities for which this object is considered a response.

pub fn location(&self) -> Option<&Item>

Gets the Project location.

Indicates one or more physical or logical locations associated with the object.

pub fn set_location<I: Into<Item>>(&mut self, val: I)

Sets the Project location.

Indicates one or more physical or logical locations associated with the object.

pub fn unset_location(&mut self) -> Option<Box<Item>>

Unsets the Project location.

Indicates one or more physical or logical locations associated with the object.

pub fn with_location<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project location.

Indicates one or more physical or logical locations associated with the object.

pub fn preview(&self) -> Option<&Item>

Gets the Project preview.

Identifies an entity that provides a preview of this object.

pub fn set_preview<I: Into<Item>>(&mut self, val: I)

Sets the Project preview.

Identifies an entity that provides a preview of this object.

pub fn unset_preview(&mut self) -> Option<Box<Item>>

Unsets the Project preview.

Identifies an entity that provides a preview of this object.

pub fn with_preview<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project preview.

Identifies an entity that provides a preview of this object.

pub fn replies(&self) -> Option<&Collection>

Gets the Project replies.

Identifies a Collection containing objects considered to be responses to this object.

pub fn set_replies<I: Into<Collection>>(&mut self, val: I)

Sets the Project replies.

Identifies a Collection containing objects considered to be responses to this object.

pub fn unset_replies(&mut self) -> Option<Box<Collection>>

Unsets the Project replies.

Identifies a Collection containing objects considered to be responses to this object.

pub fn with_replies<I: Into<Collection>>(self, val: I) -> Self

Builder function that sets the Project replies.

Identifies a Collection containing objects considered to be responses to this object.

pub fn tag(&self) -> Option<&Items>

Gets the Project tag.

One or more “tags” that have been associated with an objects.

A tag can be any kind of Object.

The key difference between attachment and tag is that the former implies association by inclusion,

while the latter implies associated by reference.

pub fn set_tag<I: Into<Items>>(&mut self, val: I)

Sets the Project tag.

One or more “tags” that have been associated with an objects.

A tag can be any kind of Object.

The key difference between attachment and tag is that the former implies association by inclusion,

while the latter implies associated by reference.

pub fn unset_tag(&mut self) -> Option<Box<Items>>

Unsets the Project tag.

One or more “tags” that have been associated with an objects.

A tag can be any kind of Object.

The key difference between attachment and tag is that the former implies association by inclusion,

while the latter implies associated by reference.

pub fn with_tag<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project tag.

One or more “tags” that have been associated with an objects.

A tag can be any kind of Object.

The key difference between attachment and tag is that the former implies association by inclusion,

while the latter implies associated by reference.

pub fn to(&self) -> Option<&Items>

Gets the Project to.

Identifies one or more entities that are part of the public primary audience of this Object.

pub fn set_to<I: Into<Items>>(&mut self, val: I)

Sets the Project to.

Identifies one or more entities that are part of the public primary audience of this Object.

pub fn unset_to(&mut self) -> Option<Box<Items>>

Unsets the Project to.

Identifies one or more entities that are part of the public primary audience of this Object.

pub fn with_to<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project to.

Identifies one or more entities that are part of the public primary audience of this Object.

pub fn bto(&self) -> Option<&Items>

Gets the Project bto.

Identifies one or more entities that are part of the private primary audience of this Object.

pub fn set_bto<I: Into<Items>>(&mut self, val: I)

Sets the Project bto.

Identifies one or more entities that are part of the private primary audience of this Object.

pub fn unset_bto(&mut self) -> Option<Box<Items>>

Unsets the Project bto.

Identifies one or more entities that are part of the private primary audience of this Object.

pub fn with_bto<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project bto.

Identifies one or more entities that are part of the private primary audience of this Object.

pub fn cc(&self) -> Option<&Items>

Gets the Project cc.

Identifies one or more entities that are part of the public secondary audience of this Object.

pub fn set_cc<I: Into<Items>>(&mut self, val: I)

Sets the Project cc.

Identifies one or more entities that are part of the public secondary audience of this Object.

pub fn unset_cc(&mut self) -> Option<Box<Items>>

Unsets the Project cc.

Identifies one or more entities that are part of the public secondary audience of this Object.

pub fn with_cc<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project cc.

Identifies one or more entities that are part of the public secondary audience of this Object.

pub fn bcc(&self) -> Option<&Items>

Gets the Project bcc.

Identifies one or more entities that are part of the private secondary audience of this Object.

pub fn set_bcc<I: Into<Items>>(&mut self, val: I)

Sets the Project bcc.

Identifies one or more entities that are part of the private secondary audience of this Object.

pub fn unset_bcc(&mut self) -> Option<Box<Items>>

Unsets the Project bcc.

Identifies one or more entities that are part of the private secondary audience of this Object.

pub fn with_bcc<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project bcc.

Identifies one or more entities that are part of the private secondary audience of this Object.

pub fn extra_fields(&self) -> Option<&Map<String, Value>>

Gets the Project extra_fields.

pub fn set_extra_fields<I: Into<Map<String, Value>>>(&mut self, val: I)

Sets the Project extra_fields.

pub fn unset_extra_fields(&mut self) -> Option<Box<Map<String, Value>>>

Unsets the Project extra_fields.

pub fn with_extra_fields<I: Into<Map<String, Value>>>(self, val: I) -> Self

Builder function that sets the Project extra_fields.

Source

impl<Vocab: ActivityVocabulary> Project<Vocab>

pub const fn media_type(&self) -> Option<MimeType>

Gets the Project media_type.

When used on a Link, identifies the MIME media type of the referenced resource.

When used on an Object, identifies the MIME media type of the value of the content property.

If not specified, the content property is assumed to contain text/html content.

pub fn set_media_type<I: Into<MimeType>>(&mut self, val: I)

Sets the Project media_type.

When used on a Link, identifies the MIME media type of the referenced resource.

When used on an Object, identifies the MIME media type of the value of the content property.

If not specified, the content property is assumed to contain text/html content.

pub fn unset_media_type(&mut self) -> Option<MimeType>

Unsets the Project media_type.

When used on a Link, identifies the MIME media type of the referenced resource.

When used on an Object, identifies the MIME media type of the value of the content property.

If not specified, the content property is assumed to contain text/html content.

pub fn with_media_type<I: Into<MimeType>>(self, val: I) -> Self

Builder function that sets the Project media_type.

When used on a Link, identifies the MIME media type of the referenced resource.

When used on an Object, identifies the MIME media type of the value of the content property.

If not specified, the content property is assumed to contain text/html content.

pub const fn start_time(&self) -> Option<DateTime>

Gets the Project start_time.

The date and time describing the actual or expected starting time of the object.

When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.

pub fn set_start_time<I: Into<DateTime>>(&mut self, val: I)

Sets the Project start_time.

The date and time describing the actual or expected starting time of the object.

When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.

pub fn unset_start_time(&mut self) -> Option<DateTime>

Unsets the Project start_time.

The date and time describing the actual or expected starting time of the object.

When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.

pub fn with_start_time<I: Into<DateTime>>(self, val: I) -> Self

Builder function that sets the Project start_time.

The date and time describing the actual or expected starting time of the object.

When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.

pub const fn end_time(&self) -> Option<DateTime>

Gets the Project end_time.

The date and time describing the actual or expected ending time of the object.

When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.

pub fn set_end_time<I: Into<DateTime>>(&mut self, val: I)

Sets the Project end_time.

The date and time describing the actual or expected ending time of the object.

When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.

pub fn unset_end_time(&mut self) -> Option<DateTime>

Unsets the Project end_time.

The date and time describing the actual or expected ending time of the object.

When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.

pub fn with_end_time<I: Into<DateTime>>(self, val: I) -> Self

Builder function that sets the Project end_time.

The date and time describing the actual or expected ending time of the object.

When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.

pub const fn published(&self) -> Option<DateTime>

Gets the Project published.

The date and time at which the object was published.

pub fn set_published<I: Into<DateTime>>(&mut self, val: I)

Sets the Project published.

The date and time at which the object was published.

pub fn unset_published(&mut self) -> Option<DateTime>

Unsets the Project published.

The date and time at which the object was published.

pub fn with_published<I: Into<DateTime>>(self, val: I) -> Self

Builder function that sets the Project published.

The date and time at which the object was published.

pub const fn updated(&self) -> Option<DateTime>

Gets the Project updated.

The date and time at which the object was updated.

pub fn set_updated<I: Into<DateTime>>(&mut self, val: I)

Sets the Project updated.

The date and time at which the object was updated.

pub fn unset_updated(&mut self) -> Option<DateTime>

Unsets the Project updated.

The date and time at which the object was updated.

pub fn with_updated<I: Into<DateTime>>(self, val: I) -> Self

Builder function that sets the Project updated.

The date and time at which the object was updated.

Source

impl<Vocab: ActivityVocabulary> Project<Vocab>

pub fn inbox(&self) -> Option<&Item>

Gets the Project inbox.

A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.

pub fn set_inbox<I: Into<Item>>(&mut self, val: I)

Sets the Project inbox.

A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.

pub fn unset_inbox(&mut self) -> Option<Item>

Unsets the Project inbox.

A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.

pub fn with_inbox<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project inbox.

A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.

pub fn outbox(&self) -> Option<&Item>

Gets the Project outbox.

An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.

pub fn set_outbox<I: Into<Item>>(&mut self, val: I)

Sets the Project outbox.

An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.

pub fn unset_outbox(&mut self) -> Option<Item>

Unsets the Project outbox.

An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.

pub fn with_outbox<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project outbox.

An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.

pub fn following(&self) -> Option<&Item>

Gets the Project following.

A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.

pub fn set_following<I: Into<Item>>(&mut self, val: I)

Sets the Project following.

A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.

pub fn unset_following(&mut self) -> Option<Item>

Unsets the Project following.

A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.

pub fn with_following<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project following.

A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.

pub fn followers(&self) -> Option<&Item>

Gets the Project followers.

A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.

pub fn set_followers<I: Into<Item>>(&mut self, val: I)

Sets the Project followers.

A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.

pub fn unset_followers(&mut self) -> Option<Item>

Unsets the Project followers.

A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.

pub fn with_followers<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project followers.

A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.

pub fn liked(&self) -> Option<&Item>

Gets the Project liked.

A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.

pub fn set_liked<I: Into<Item>>(&mut self, val: I)

Sets the Project liked.

A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.

pub fn unset_liked(&mut self) -> Option<Item>

Unsets the Project liked.

A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.

pub fn with_liked<I: Into<Item>>(self, val: I) -> Self

Builder function that sets the Project liked.

A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.

pub fn streams(&self) -> Option<&Items>

Gets the Project streams.

A list of supplementary Collections which may be of interest.

pub fn set_streams<I: Into<Items>>(&mut self, val: I)

Sets the Project streams.

A list of supplementary Collections which may be of interest.

pub fn unset_streams(&mut self) -> Option<Items>

Unsets the Project streams.

A list of supplementary Collections which may be of interest.

pub fn with_streams<I: Into<Items>>(self, val: I) -> Self

Builder function that sets the Project streams.

A list of supplementary Collections which may be of interest.

pub fn preferred_username(&self) -> Option<&Name>

Gets the Project preferred_username.

A short username which may be used to refer to the actor, with no uniqueness guarantees.

pub fn set_preferred_username<I: Into<Name>>(&mut self, val: I)

Sets the Project preferred_username.

A short username which may be used to refer to the actor, with no uniqueness guarantees.

pub fn unset_preferred_username(&mut self) -> Option<Name>

Unsets the Project preferred_username.

A short username which may be used to refer to the actor, with no uniqueness guarantees.

pub fn with_preferred_username<I: Into<Name>>(self, val: I) -> Self

Builder function that sets the Project preferred_username.

A short username which may be used to refer to the actor, with no uniqueness guarantees.

pub fn endpoints(&self) -> Option<&Endpoints>

Gets the Project endpoints.

A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.

This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.

pub fn set_endpoints<I: Into<Endpoints>>(&mut self, val: I)

Sets the Project endpoints.

A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.

This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.

pub fn unset_endpoints(&mut self) -> Option<Endpoints>

Unsets the Project endpoints.

A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.

This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.

pub fn with_endpoints<I: Into<Endpoints>>(self, val: I) -> Self

Builder function that sets the Project endpoints.

A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.

This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.

pub fn assertion_method(&self) -> Option<&MultikeyItems>

Gets the Project assertion_method.

A list of public key representations following the FEP-521a specification.

pub fn set_assertion_method<I: Into<MultikeyItems>>(&mut self, val: I)

Sets the Project assertion_method.

A list of public key representations following the FEP-521a specification.

pub fn unset_assertion_method(&mut self) -> Option<MultikeyItems>

Unsets the Project assertion_method.

A list of public key representations following the FEP-521a specification.

pub fn with_assertion_method<I: Into<MultikeyItems>>(self, val: I) -> Self

Builder function that sets the Project assertion_method.

A list of public key representations following the FEP-521a specification.

pub fn public_key(&self) -> Option<&KeyItems>

👎Deprecated since 0.3.0:

The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.

Gets the Project public_key.

Public key used for HTTP Signatures and Linked Data Signatures.

pub fn set_public_key<I: Into<KeyItems>>(&mut self, val: I)

👎Deprecated since 0.3.0:

The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.

Sets the Project public_key.

Public key used for HTTP Signatures and Linked Data Signatures.

pub fn unset_public_key(&mut self) -> Option<KeyItems>

👎Deprecated since 0.3.0:

The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.

Unsets the Project public_key.

Public key used for HTTP Signatures and Linked Data Signatures.

pub fn with_public_key<I: Into<KeyItems>>(self, val: I) -> Self

👎Deprecated since 0.3.0:

The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.

Builder function that sets the Project public_key.

Public key used for HTTP Signatures and Linked Data Signatures.

Source

impl Project

pub fn components(&self) -> Option<&Collection>

Gets the Project components.

Identifies a Collection listing actors whose services and resources are considered to be components of this project.

The collection items are Relationship objects whose relationship is hasComponent and whose instrument is the maximal role allowed for delegation, specified when the component was added.

pub fn set_components<I: Into<Collection>>(&mut self, val: I)

Sets the Project components.

Identifies a Collection listing actors whose services and resources are considered to be components of this project.

The collection items are Relationship objects whose relationship is hasComponent and whose instrument is the maximal role allowed for delegation, specified when the component was added.

pub fn unset_components(&mut self) -> Option<Collection>

Unsets the Project components.

Identifies a Collection listing actors whose services and resources are considered to be components of this project.

The collection items are Relationship objects whose relationship is hasComponent and whose instrument is the maximal role allowed for delegation, specified when the component was added.

pub fn with_components<I: Into<Collection>>(self, val: I) -> Self

Builder function that sets the Project components.

Identifies a Collection listing actors whose services and resources are considered to be components of this project.

The collection items are Relationship objects whose relationship is hasComponent and whose instrument is the maximal role allowed for delegation, specified when the component was added.