Skip to main contentModule actor
Source - Factory
- A service actor that creates resource actors (such as
Repository), exists to allow access control on creation of remote resources. - PatchTracker
- Represents a tracker of merge requests, i.e. a project managing a list of patches or branches submitted as proposed changes to a given Repository.
- Project
- Represents a project, a planned endeavor that involves usage of tools related to the software development lifecycle.
- ReleaseTracker
- Manages a set of software releases for a given Repository.
- Repository
- Represents a version control system repository.
- Roadmap
- Manages a set of project milestones under which issues and MRs can be grouped.
- Team
- Represents a group of people working together, collaborating on shared resources.
- TicketTracker
- Represents a ticket tracker, i.e. a project managing a list of work items.
- Workflow
- Manages a set of custom labels and properties of tickets and MRs, as well as the possible transitions between property values.
- PatchTrackerItem
- Represents a field range that can either be a PatchTracker or Iri.