pub struct Workflow<Vocab: ActivityVocabulary = VocabularyTypes> { /* private fields */ }Expand description
Manages a set of custom labels and properties of tickets and MRs, as well as the possible transitions between property values.
Example (single vocabulary type)
use activityforge::{Workflow, context};
use activitystreams_vocabulary::{
Iri, MultibaseHeader, MultibasePublicKey, Multikey, MultikeyPublicKey, Name,
};
let id = Iri::try_from("https://dev.example/aviva/treesim").unwrap();
let name = Name::try_from("Tree Growth 3D Simulation").unwrap();
let summary = "<p>Tree growth 3D simulator for my nature exploration game</p>";
let inbox = Iri::try_from("https://dev.example/aviva/treesim/inbox").unwrap();
let outbox = Iri::try_from("https://dev.example/aviva/treesim/outbox").unwrap();
let followers = Iri::try_from("https://dev.example/aviva/treesim/followers").unwrap();
let key_id = Iri::try_from("https://dev.example/aviva/treesim#main-key").unwrap();
let controller = Iri::try_from("https://dev.example/aviva/treesim").unwrap();
let encoded_multibase = "u7QGwDY2Tjn93PVFWWq02piP1NE9_XRlg-c8-jhJiHqKBHw";
let team = Iri::try_from("https://dev.example/aviva/treesim/team").unwrap();
let json_str = format!(
r#"{{
"@context": [
"https://www.w3.org/ns/activitystreams",
"https://forgefed.org/ns"
],
"type": "Workflow",
"id": "{id}",
"name": "{name}",
"summary": "{summary}",
"inbox": "{inbox}",
"outbox": "{outbox}",
"followers": "{followers}",
"assertionMethod": [
{{
"type": "Multikey",
"id": "{key_id}",
"controller": "{controller}",
"publicKeyMultibase": "{encoded_multibase}"
}}
]
}}"#
);
let context = context::forgefed_context();
let multibase = MultibasePublicKey::new()
.with_header(MultibaseHeader::Base64UrlNoPad)
.with_key(MultikeyPublicKey::Ed25519([
0xb0, 0x0d, 0x8d, 0x93, 0x8e, 0x7f, 0x77, 0x3d, 0x51, 0x56, 0x5a, 0xad, 0x36, 0xa6,
0x23, 0xf5, 0x34, 0x4f, 0x7f, 0x5d, 0x19, 0x60, 0xf9, 0xcf, 0x3e, 0x8e, 0x12, 0x62,
0x1e, 0xa2, 0x81, 0x1f,
]));
let multikey = Multikey::new_inner()
.with_id(key_id)
.with_controller(controller.clone())
.with_public_key_multibase(multibase);
let repository = Workflow::new()
.with_context_property(context)
.with_id(id)
.with_name(name)
.with_summary(summary)
.with_inbox(inbox)
.with_outbox(outbox)
.with_followers(followers)
.with_assertion_method([multikey]);
assert_eq!(serde_json::to_string_pretty(&repository).unwrap(), json_str);
assert_eq!(
serde_json::from_str::<Workflow>(json_str.as_str()).unwrap(),
repository
);Example (list of vocabulary types)
use activityforge::{ActorType, Workflow, VocabularyTypes, context};
use activitystreams_vocabulary::{
Iri, MultibaseHeader, MultibasePublicKey, Multikey, MultikeyPublicKey, Name,
};
let id = Iri::try_from("https://dev.example/aviva/treesim").unwrap();
let name = Name::try_from("Tree Growth 3D Simulation").unwrap();
let summary = "<p>Tree growth 3D simulator for my nature exploration game</p>";
let inbox = Iri::try_from("https://dev.example/aviva/treesim/inbox").unwrap();
let outbox = Iri::try_from("https://dev.example/aviva/treesim/outbox").unwrap();
let followers = Iri::try_from("https://dev.example/aviva/treesim/followers").unwrap();
let key_id = Iri::try_from("https://dev.example/aviva/treesim#main-key").unwrap();
let controller = Iri::try_from("https://dev.example/aviva/treesim").unwrap();
let encoded_multibase = "u7QGwDY2Tjn93PVFWWq02piP1NE9_XRlg-c8-jhJiHqKBHw";
let team = Iri::try_from("https://dev.example/aviva/treesim/team").unwrap();
let json_str = format!(
r#"{{
"@context": [
"https://www.w3.org/ns/activitystreams",
"https://forgefed.org/ns"
],
"type": [
"Repository",
"Workflow"
],
"id": "{id}",
"name": "{name}",
"summary": "{summary}",
"inbox": "{inbox}",
"outbox": "{outbox}",
"followers": "{followers}",
"assertionMethod": [
{{
"type": "Multikey",
"id": "{key_id}",
"controller": "{controller}",
"publicKeyMultibase": "{encoded_multibase}"
}}
]
}}"#
);
let context = context::forgefed_context();
let multibase = MultibasePublicKey::new()
.with_header(MultibaseHeader::Base64UrlNoPad)
.with_key(MultikeyPublicKey::Ed25519([
0xb0, 0x0d, 0x8d, 0x93, 0x8e, 0x7f, 0x77, 0x3d, 0x51, 0x56, 0x5a, 0xad, 0x36, 0xa6,
0x23, 0xf5, 0x34, 0x4f, 0x7f, 0x5d, 0x19, 0x60, 0xf9, 0xcf, 0x3e, 0x8e, 0x12, 0x62,
0x1e, 0xa2, 0x81, 0x1f,
]));
let multikey = Multikey::new_inner()
.with_id(key_id)
.with_controller(controller.clone())
.with_public_key_multibase(multibase);
let repository = Workflow::new()
.with_context_property(context)
.with_kind(VocabularyTypes::list([
ActorType::Repository,
ActorType::Workflow,
]))
.with_id(id)
.with_name(name)
.with_summary(summary)
.with_inbox(inbox)
.with_outbox(outbox)
.with_followers(followers)
.with_assertion_method([multikey]);
assert_eq!(serde_json::to_string_pretty(&repository).unwrap(), json_str);
assert_eq!(
serde_json::from_str::<Workflow>(json_str.as_str()).unwrap(),
repository
);Implementations
Sourceimpl<Vocab: ActivityVocabulary + From<ActorType>> Workflow<Vocab>
impl<Vocab: ActivityVocabulary + From<ActorType>> Workflow<Vocab>
Sourcepub fn new_inner() -> Self
pub fn new_inner() -> Self
Creates a new Workflow for use as an inner member of another object.
Encodes the type without the @context field.
Sourcepub fn without_context_property(self) -> Self
pub fn without_context_property(self) -> Self
Builder function that unsets the @context field.
Sourceimpl<Vocab: ActivityVocabulary> Workflow<Vocab>
impl<Vocab: ActivityVocabulary> Workflow<Vocab>
Sourceimpl<Vocab: ActivityVocabulary> Workflow<Vocab>
impl<Vocab: ActivityVocabulary> Workflow<Vocab>
Sourcepub fn context_property(&self) -> Option<&Context>
pub fn context_property(&self) -> Option<&Context>
Sourcepub fn set_context_property<I: Into<Context>>(&mut self, val: I)
pub fn set_context_property<I: Into<Context>>(&mut self, val: I)
Sourcepub fn unset_context_property(&mut self) -> Option<Context>
pub fn unset_context_property(&mut self) -> Option<Context>
Sourcepub fn with_context_property<I: Into<Context>>(self, val: I) -> Self
pub fn with_context_property<I: Into<Context>>(self, val: I) -> Self
Sourcepub fn name(&self) -> Option<&Name>
pub fn name(&self) -> Option<&Name>
Gets the Workflow name.
A simple, human-readable, plain-text name for the object.
HTML markup MUST NOT be included.
The name MAY be expressed using multiple language-tagged values.
Sourcepub fn set_name<I: Into<Name>>(&mut self, val: I)
pub fn set_name<I: Into<Name>>(&mut self, val: I)
Sets the Workflow name.
A simple, human-readable, plain-text name for the object.
HTML markup MUST NOT be included.
The name MAY be expressed using multiple language-tagged values.
Sourcepub fn unset_name(&mut self) -> Option<Name>
pub fn unset_name(&mut self) -> Option<Name>
Unsets the Workflow name.
A simple, human-readable, plain-text name for the object.
HTML markup MUST NOT be included.
The name MAY be expressed using multiple language-tagged values.
Sourcepub fn with_name<I: Into<Name>>(self, val: I) -> Self
pub fn with_name<I: Into<Name>>(self, val: I) -> Self
Builder function that sets the Workflow name.
A simple, human-readable, plain-text name for the object.
HTML markup MUST NOT be included.
The name MAY be expressed using multiple language-tagged values.
Sourcepub fn name_map(&self) -> Option<&NameMap>
pub fn name_map(&self) -> Option<&NameMap>
Gets the Workflow name_map.
A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.
HTML markup MUST NOT be included.
Sourcepub fn set_name_map<I: Into<NameMap>>(&mut self, val: I)
pub fn set_name_map<I: Into<NameMap>>(&mut self, val: I)
Sets the Workflow name_map.
A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.
HTML markup MUST NOT be included.
Sourcepub fn unset_name_map(&mut self) -> Option<NameMap>
pub fn unset_name_map(&mut self) -> Option<NameMap>
Unsets the Workflow name_map.
A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.
HTML markup MUST NOT be included.
Sourcepub fn with_name_map<I: Into<NameMap>>(self, val: I) -> Self
pub fn with_name_map<I: Into<NameMap>>(self, val: I) -> Self
Builder function that sets the Workflow name_map.
A simple, human-readable, plain-text name for the object expressed using multiple language-tagged values.
HTML markup MUST NOT be included.
Sourcepub fn content_map(&self) -> Option<&LanguageMap>
pub fn content_map(&self) -> Option<&LanguageMap>
Sourcepub fn set_content_map<I: Into<LanguageMap>>(&mut self, val: I)
pub fn set_content_map<I: Into<LanguageMap>>(&mut self, val: I)
Sourcepub fn unset_content_map(&mut self) -> Option<LanguageMap>
pub fn unset_content_map(&mut self) -> Option<LanguageMap>
Sourcepub fn with_content_map<I: Into<LanguageMap>>(self, val: I) -> Self
pub fn with_content_map<I: Into<LanguageMap>>(self, val: I) -> Self
Builder function that sets the Workflow content_map.
The content or textual representation of the Object encoded as a JSON string, expressed using multiple language-tagged values.
By default, the value of content is HTML.
The mediaType property can be used in the object to indicate a different content type.
Sourcepub fn summary_map(&self) -> Option<&LanguageMap>
pub fn summary_map(&self) -> Option<&LanguageMap>
Gets the Workflow summary_map.
A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.
Sourcepub fn set_summary_map<I: Into<LanguageMap>>(&mut self, val: I)
pub fn set_summary_map<I: Into<LanguageMap>>(&mut self, val: I)
Sets the Workflow summary_map.
A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.
Sourcepub fn unset_summary_map(&mut self) -> Option<LanguageMap>
pub fn unset_summary_map(&mut self) -> Option<LanguageMap>
Unsets the Workflow summary_map.
A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.
Sourcepub fn with_summary_map<I: Into<LanguageMap>>(self, val: I) -> Self
pub fn with_summary_map<I: Into<LanguageMap>>(self, val: I) -> Self
Builder function that sets the Workflow summary_map.
A natural language summarization of the object encoded as HTML, expressed as multiple language-tagged summaries.
Sourcepub fn duration(&self) -> Option<&Duration>
pub fn duration(&self) -> Option<&Duration>
Gets the Workflow duration.
When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.
The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.
Sourcepub fn set_duration<I: Into<Duration>>(&mut self, val: I)
pub fn set_duration<I: Into<Duration>>(&mut self, val: I)
Sets the Workflow duration.
When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.
The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.
Sourcepub fn unset_duration(&mut self) -> Option<Duration>
pub fn unset_duration(&mut self) -> Option<Duration>
Unsets the Workflow duration.
When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.
The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.
Sourcepub fn with_duration<I: Into<Duration>>(self, val: I) -> Self
pub fn with_duration<I: Into<Duration>>(self, val: I) -> Self
Builder function that sets the Workflow duration.
When the object describes a time-bound resource, such as an audio or video, a meeting, etc, the duration property indicates the object’s approximate duration.
The value MUST be expressed as an xsd:duration as defined by xmlschema11-2.
Sourcepub fn source(&self) -> Option<&ContentItem>
pub fn source(&self) -> Option<&ContentItem>
Gets the Workflow source.
Represents the source of the content field.
Sourcepub fn set_source<I: Into<ContentItem>>(&mut self, val: I)
pub fn set_source<I: Into<ContentItem>>(&mut self, val: I)
Sets the Workflow source.
Represents the source of the content field.
Sourcepub fn unset_source(&mut self) -> Option<ContentItem>
pub fn unset_source(&mut self) -> Option<ContentItem>
Unsets the Workflow source.
Represents the source of the content field.
Sourcepub fn with_source<I: Into<ContentItem>>(self, val: I) -> Self
pub fn with_source<I: Into<ContentItem>>(self, val: I) -> Self
Builder function that sets the Workflow source.
Represents the source of the content field.
Sourcepub fn proof(&self) -> Option<&DataIntegrityProof>
pub fn proof(&self) -> Option<&DataIntegrityProof>
Gets the Workflow proof.
Represents a DataIntegrityProof.
Sourcepub fn set_proof<I: Into<DataIntegrityProof>>(&mut self, val: I)
pub fn set_proof<I: Into<DataIntegrityProof>>(&mut self, val: I)
Sets the Workflow proof.
Represents a DataIntegrityProof.
Sourcepub fn unset_proof(&mut self) -> Option<DataIntegrityProof>
pub fn unset_proof(&mut self) -> Option<DataIntegrityProof>
Unsets the Workflow proof.
Represents a DataIntegrityProof.
Sourcepub fn with_proof<I: Into<DataIntegrityProof>>(self, val: I) -> Self
pub fn with_proof<I: Into<DataIntegrityProof>>(self, val: I) -> Self
Builder function that sets the Workflow proof.
Represents a DataIntegrityProof.
Sourcepub fn url(&self) -> Option<&LinkItems>
pub fn url(&self) -> Option<&LinkItems>
Gets the Workflow url.
Identifies one or more links to representations of the object
Sourcepub fn set_url<I: Into<LinkItems>>(&mut self, val: I)
pub fn set_url<I: Into<LinkItems>>(&mut self, val: I)
Sets the Workflow url.
Identifies one or more links to representations of the object
Sourceimpl<Vocab: ActivityVocabulary> Workflow<Vocab>
impl<Vocab: ActivityVocabulary> Workflow<Vocab>
Sourcepub fn content(&self) -> Option<&str>
pub fn content(&self) -> Option<&str>
Gets the Workflow content.
The content or textual representation of the Object encoded as a JSON string.
By default, the value of content is HTML.
The mediaType property can be used in the object to indicate a different content type.
The content MAY be expressed using multiple language-tagged values.
Sourcepub fn set_content<I: Into<String>>(&mut self, val: I)
pub fn set_content<I: Into<String>>(&mut self, val: I)
Sets the Workflow content.
The content or textual representation of the Object encoded as a JSON string.
By default, the value of content is HTML.
The mediaType property can be used in the object to indicate a different content type.
The content MAY be expressed using multiple language-tagged values.
Sourcepub fn unset_content(&mut self) -> Option<String>
pub fn unset_content(&mut self) -> Option<String>
Unsets the Workflow content.
The content or textual representation of the Object encoded as a JSON string.
By default, the value of content is HTML.
The mediaType property can be used in the object to indicate a different content type.
The content MAY be expressed using multiple language-tagged values.
Sourcepub fn with_content<I: Into<String>>(self, val: I) -> Self
pub fn with_content<I: Into<String>>(self, val: I) -> Self
Builder function that sets the Workflow content.
The content or textual representation of the Object encoded as a JSON string.
By default, the value of content is HTML.
The mediaType property can be used in the object to indicate a different content type.
The content MAY be expressed using multiple language-tagged values.
Sourcepub fn summary(&self) -> Option<&str>
pub fn summary(&self) -> Option<&str>
Gets the Workflow summary.
A natural language summarization of the object encoded as HTML.
Multiple language tagged summaries MAY be provided.
Sourcepub fn set_summary<I: Into<String>>(&mut self, val: I)
pub fn set_summary<I: Into<String>>(&mut self, val: I)
Sets the Workflow summary.
A natural language summarization of the object encoded as HTML.
Multiple language tagged summaries MAY be provided.
Sourcepub fn unset_summary(&mut self) -> Option<String>
pub fn unset_summary(&mut self) -> Option<String>
Unsets the Workflow summary.
A natural language summarization of the object encoded as HTML.
Multiple language tagged summaries MAY be provided.
Sourcepub fn with_summary<I: Into<String>>(self, val: I) -> Self
pub fn with_summary<I: Into<String>>(self, val: I) -> Self
Builder function that sets the Workflow summary.
A natural language summarization of the object encoded as HTML.
Multiple language tagged summaries MAY be provided.
Sourceimpl<Vocab: ActivityVocabulary> Workflow<Vocab>
impl<Vocab: ActivityVocabulary> Workflow<Vocab>
Sourcepub fn attachment(&self) -> Option<&Items>
pub fn attachment(&self) -> Option<&Items>
Gets the Workflow attachment.
Identifies a resource attached or related to an object that potentially requires special handling.
The intent is to provide a model that is at least semantically similar to attachments in email.
Sourcepub fn set_attachment<I: Into<Items>>(&mut self, val: I)
pub fn set_attachment<I: Into<Items>>(&mut self, val: I)
Sets the Workflow attachment.
Identifies a resource attached or related to an object that potentially requires special handling.
The intent is to provide a model that is at least semantically similar to attachments in email.
Sourcepub fn unset_attachment(&mut self) -> Option<Box<Items>>
pub fn unset_attachment(&mut self) -> Option<Box<Items>>
Unsets the Workflow attachment.
Identifies a resource attached or related to an object that potentially requires special handling.
The intent is to provide a model that is at least semantically similar to attachments in email.
Sourcepub fn with_attachment<I: Into<Items>>(self, val: I) -> Self
pub fn with_attachment<I: Into<Items>>(self, val: I) -> Self
Builder function that sets the Workflow attachment.
Identifies a resource attached or related to an object that potentially requires special handling.
The intent is to provide a model that is at least semantically similar to attachments in email.
Sourcepub fn attributed_to(&self) -> Option<&Item>
pub fn attributed_to(&self) -> Option<&Item>
Gets the Workflow attributed_to.
Identifies one or more entities to which this object is attributed.
The attributed entities might not be Actors.
For instance, an object might be attributed to the completion of another activity.
Sourcepub fn set_attributed_to<I: Into<Item>>(&mut self, val: I)
pub fn set_attributed_to<I: Into<Item>>(&mut self, val: I)
Sets the Workflow attributed_to.
Identifies one or more entities to which this object is attributed.
The attributed entities might not be Actors.
For instance, an object might be attributed to the completion of another activity.
Sourcepub fn unset_attributed_to(&mut self) -> Option<Box<Item>>
pub fn unset_attributed_to(&mut self) -> Option<Box<Item>>
Unsets the Workflow attributed_to.
Identifies one or more entities to which this object is attributed.
The attributed entities might not be Actors.
For instance, an object might be attributed to the completion of another activity.
Sourcepub fn with_attributed_to<I: Into<Item>>(self, val: I) -> Self
pub fn with_attributed_to<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow attributed_to.
Identifies one or more entities to which this object is attributed.
The attributed entities might not be Actors.
For instance, an object might be attributed to the completion of another activity.
Sourcepub fn audience(&self) -> Option<&Item>
pub fn audience(&self) -> Option<&Item>
Gets the Workflow audience.
Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.
Sourcepub fn set_audience<I: Into<Item>>(&mut self, val: I)
pub fn set_audience<I: Into<Item>>(&mut self, val: I)
Sets the Workflow audience.
Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.
Sourcepub fn unset_audience(&mut self) -> Option<Box<Item>>
pub fn unset_audience(&mut self) -> Option<Box<Item>>
Unsets the Workflow audience.
Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.
Sourcepub fn with_audience<I: Into<Item>>(self, val: I) -> Self
pub fn with_audience<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow audience.
Identifies one or more entities that represent the total population of entities for which the object can be considered to be relevant.
Sourcepub fn context(&self) -> Option<&Item>
pub fn context(&self) -> Option<&Item>
Gets the Workflow context.
Identifies the context within which the object exists or an activity was performed.
The notion of “context” used is intentionally vague.
The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.
An example could be all activities relating to a common project or event.
Sourcepub fn set_context<I: Into<Item>>(&mut self, val: I)
pub fn set_context<I: Into<Item>>(&mut self, val: I)
Sets the Workflow context.
Identifies the context within which the object exists or an activity was performed.
The notion of “context” used is intentionally vague.
The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.
An example could be all activities relating to a common project or event.
Sourcepub fn unset_context(&mut self) -> Option<Box<Item>>
pub fn unset_context(&mut self) -> Option<Box<Item>>
Unsets the Workflow context.
Identifies the context within which the object exists or an activity was performed.
The notion of “context” used is intentionally vague.
The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.
An example could be all activities relating to a common project or event.
Sourcepub fn with_context<I: Into<Item>>(self, val: I) -> Self
pub fn with_context<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow context.
Identifies the context within which the object exists or an activity was performed.
The notion of “context” used is intentionally vague.
The intended function is to serve as a means of grouping objects and activities that share a common originating context or purpose.
An example could be all activities relating to a common project or event.
Sourcepub fn generator(&self) -> Option<&Item>
pub fn generator(&self) -> Option<&Item>
Gets the Workflow generator.
Identifies the entity (e.g. an application) that generated the object.
Sourcepub fn set_generator<I: Into<Item>>(&mut self, val: I)
pub fn set_generator<I: Into<Item>>(&mut self, val: I)
Sets the Workflow generator.
Identifies the entity (e.g. an application) that generated the object.
Sourcepub fn unset_generator(&mut self) -> Option<Box<Item>>
pub fn unset_generator(&mut self) -> Option<Box<Item>>
Unsets the Workflow generator.
Identifies the entity (e.g. an application) that generated the object.
Sourcepub fn with_generator<I: Into<Item>>(self, val: I) -> Self
pub fn with_generator<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow generator.
Identifies the entity (e.g. an application) that generated the object.
Sourcepub fn icon(&self) -> Option<&ImageItem>
pub fn icon(&self) -> Option<&ImageItem>
Gets the Workflow icon.
Indicates an entity that describes an icon for this object.
The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.
Sourcepub fn set_icon<I: Into<ImageItem>>(&mut self, val: I)
pub fn set_icon<I: Into<ImageItem>>(&mut self, val: I)
Sets the Workflow icon.
Indicates an entity that describes an icon for this object.
The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.
Sourcepub fn unset_icon(&mut self) -> Option<Box<ImageItem>>
pub fn unset_icon(&mut self) -> Option<Box<ImageItem>>
Unsets the Workflow icon.
Indicates an entity that describes an icon for this object.
The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.
Sourcepub fn with_icon<I: Into<ImageItem>>(self, val: I) -> Self
pub fn with_icon<I: Into<ImageItem>>(self, val: I) -> Self
Builder function that sets the Workflow icon.
Indicates an entity that describes an icon for this object.
The image should have an aspect ratio of one (horizontal) to one (vertical) and should be suitable for presentation at a small size.
Sourcepub fn image(&self) -> Option<&ImageItem>
pub fn image(&self) -> Option<&ImageItem>
Gets the Workflow image.
Indicates an entity that describes an image for this object.
Unlike the icon property, there are no aspect ratio or display size limitations assumed.
Sourcepub fn set_image<I: Into<ImageItem>>(&mut self, val: I)
pub fn set_image<I: Into<ImageItem>>(&mut self, val: I)
Sets the Workflow image.
Indicates an entity that describes an image for this object.
Unlike the icon property, there are no aspect ratio or display size limitations assumed.
Sourcepub fn unset_image(&mut self) -> Option<Box<ImageItem>>
pub fn unset_image(&mut self) -> Option<Box<ImageItem>>
Unsets the Workflow image.
Indicates an entity that describes an image for this object.
Unlike the icon property, there are no aspect ratio or display size limitations assumed.
Sourcepub fn with_image<I: Into<ImageItem>>(self, val: I) -> Self
pub fn with_image<I: Into<ImageItem>>(self, val: I) -> Self
Builder function that sets the Workflow image.
Indicates an entity that describes an image for this object.
Unlike the icon property, there are no aspect ratio or display size limitations assumed.
Sourcepub fn in_reply_to(&self) -> Option<&Item>
pub fn in_reply_to(&self) -> Option<&Item>
Gets the Workflow in_reply_to.
Indicates one or more entities for which this object is considered a response.
Sourcepub fn set_in_reply_to<I: Into<Item>>(&mut self, val: I)
pub fn set_in_reply_to<I: Into<Item>>(&mut self, val: I)
Sets the Workflow in_reply_to.
Indicates one or more entities for which this object is considered a response.
Sourcepub fn unset_in_reply_to(&mut self) -> Option<Box<Item>>
pub fn unset_in_reply_to(&mut self) -> Option<Box<Item>>
Unsets the Workflow in_reply_to.
Indicates one or more entities for which this object is considered a response.
Sourcepub fn with_in_reply_to<I: Into<Item>>(self, val: I) -> Self
pub fn with_in_reply_to<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow in_reply_to.
Indicates one or more entities for which this object is considered a response.
Sourcepub fn location(&self) -> Option<&Item>
pub fn location(&self) -> Option<&Item>
Gets the Workflow location.
Indicates one or more physical or logical locations associated with the object.
Sourcepub fn set_location<I: Into<Item>>(&mut self, val: I)
pub fn set_location<I: Into<Item>>(&mut self, val: I)
Sets the Workflow location.
Indicates one or more physical or logical locations associated with the object.
Sourcepub fn unset_location(&mut self) -> Option<Box<Item>>
pub fn unset_location(&mut self) -> Option<Box<Item>>
Unsets the Workflow location.
Indicates one or more physical or logical locations associated with the object.
Sourcepub fn with_location<I: Into<Item>>(self, val: I) -> Self
pub fn with_location<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow location.
Indicates one or more physical or logical locations associated with the object.
Sourcepub fn preview(&self) -> Option<&Item>
pub fn preview(&self) -> Option<&Item>
Gets the Workflow preview.
Identifies an entity that provides a preview of this object.
Sourcepub fn set_preview<I: Into<Item>>(&mut self, val: I)
pub fn set_preview<I: Into<Item>>(&mut self, val: I)
Sets the Workflow preview.
Identifies an entity that provides a preview of this object.
Sourcepub fn unset_preview(&mut self) -> Option<Box<Item>>
pub fn unset_preview(&mut self) -> Option<Box<Item>>
Unsets the Workflow preview.
Identifies an entity that provides a preview of this object.
Sourcepub fn with_preview<I: Into<Item>>(self, val: I) -> Self
pub fn with_preview<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow preview.
Identifies an entity that provides a preview of this object.
Sourcepub fn replies(&self) -> Option<&Collection>
pub fn replies(&self) -> Option<&Collection>
Gets the Workflow replies.
Identifies a Collection containing objects considered to be responses to this object.
Sourcepub fn set_replies<I: Into<Collection>>(&mut self, val: I)
pub fn set_replies<I: Into<Collection>>(&mut self, val: I)
Sets the Workflow replies.
Identifies a Collection containing objects considered to be responses to this object.
Sourcepub fn unset_replies(&mut self) -> Option<Box<Collection>>
pub fn unset_replies(&mut self) -> Option<Box<Collection>>
Unsets the Workflow replies.
Identifies a Collection containing objects considered to be responses to this object.
Sourcepub fn with_replies<I: Into<Collection>>(self, val: I) -> Self
pub fn with_replies<I: Into<Collection>>(self, val: I) -> Self
Builder function that sets the Workflow replies.
Identifies a Collection containing objects considered to be responses to this object.
Sourcepub fn set_extra_fields<I: Into<Map<String, Value>>>(&mut self, val: I)
pub fn set_extra_fields<I: Into<Map<String, Value>>>(&mut self, val: I)
Sets the Workflow extra_fields.
Sourceimpl<Vocab: ActivityVocabulary> Workflow<Vocab>
impl<Vocab: ActivityVocabulary> Workflow<Vocab>
Sourcepub const fn media_type(&self) -> Option<MimeType>
pub const fn media_type(&self) -> Option<MimeType>
Sourcepub fn set_media_type<I: Into<MimeType>>(&mut self, val: I)
pub fn set_media_type<I: Into<MimeType>>(&mut self, val: I)
Sourcepub fn unset_media_type(&mut self) -> Option<MimeType>
pub fn unset_media_type(&mut self) -> Option<MimeType>
Sourcepub fn with_media_type<I: Into<MimeType>>(self, val: I) -> Self
pub fn with_media_type<I: Into<MimeType>>(self, val: I) -> Self
Builder function that sets the Workflow media_type.
When used on a Link, identifies the MIME media type of the referenced resource.
When used on an Object, identifies the MIME media type of the value of the content property.
If not specified, the content property is assumed to contain text/html content.
Sourcepub const fn start_time(&self) -> Option<DateTime>
pub const fn start_time(&self) -> Option<DateTime>
Gets the Workflow start_time.
The date and time describing the actual or expected starting time of the object.
When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.
Sourcepub fn set_start_time<I: Into<DateTime>>(&mut self, val: I)
pub fn set_start_time<I: Into<DateTime>>(&mut self, val: I)
Sets the Workflow start_time.
The date and time describing the actual or expected starting time of the object.
When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.
Sourcepub fn unset_start_time(&mut self) -> Option<DateTime>
pub fn unset_start_time(&mut self) -> Option<DateTime>
Unsets the Workflow start_time.
The date and time describing the actual or expected starting time of the object.
When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.
Sourcepub fn with_start_time<I: Into<DateTime>>(self, val: I) -> Self
pub fn with_start_time<I: Into<DateTime>>(self, val: I) -> Self
Builder function that sets the Workflow start_time.
The date and time describing the actual or expected starting time of the object.
When used with an Activity object, for instance, the startTime property specifies the moment the activity began or is scheduled to begin.
Sourcepub const fn end_time(&self) -> Option<DateTime>
pub const fn end_time(&self) -> Option<DateTime>
Gets the Workflow end_time.
The date and time describing the actual or expected ending time of the object.
When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.
Sourcepub fn set_end_time<I: Into<DateTime>>(&mut self, val: I)
pub fn set_end_time<I: Into<DateTime>>(&mut self, val: I)
Sets the Workflow end_time.
The date and time describing the actual or expected ending time of the object.
When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.
Sourcepub fn unset_end_time(&mut self) -> Option<DateTime>
pub fn unset_end_time(&mut self) -> Option<DateTime>
Unsets the Workflow end_time.
The date and time describing the actual or expected ending time of the object.
When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.
Sourcepub fn with_end_time<I: Into<DateTime>>(self, val: I) -> Self
pub fn with_end_time<I: Into<DateTime>>(self, val: I) -> Self
Builder function that sets the Workflow end_time.
The date and time describing the actual or expected ending time of the object.
When used with an Activity object, for instance, the endTime property specifies the moment the activity concluded or is expected to conclude.
Sourcepub const fn published(&self) -> Option<DateTime>
pub const fn published(&self) -> Option<DateTime>
Gets the Workflow published.
The date and time at which the object was published.
Sourcepub fn set_published<I: Into<DateTime>>(&mut self, val: I)
pub fn set_published<I: Into<DateTime>>(&mut self, val: I)
Sets the Workflow published.
The date and time at which the object was published.
Sourcepub fn unset_published(&mut self) -> Option<DateTime>
pub fn unset_published(&mut self) -> Option<DateTime>
Unsets the Workflow published.
The date and time at which the object was published.
Sourcepub fn with_published<I: Into<DateTime>>(self, val: I) -> Self
pub fn with_published<I: Into<DateTime>>(self, val: I) -> Self
Builder function that sets the Workflow published.
The date and time at which the object was published.
Sourcepub const fn updated(&self) -> Option<DateTime>
pub const fn updated(&self) -> Option<DateTime>
Gets the Workflow updated.
The date and time at which the object was updated.
Sourcepub fn set_updated<I: Into<DateTime>>(&mut self, val: I)
pub fn set_updated<I: Into<DateTime>>(&mut self, val: I)
Sets the Workflow updated.
The date and time at which the object was updated.
Sourcepub fn unset_updated(&mut self) -> Option<DateTime>
pub fn unset_updated(&mut self) -> Option<DateTime>
Unsets the Workflow updated.
The date and time at which the object was updated.
Sourcepub fn with_updated<I: Into<DateTime>>(self, val: I) -> Self
pub fn with_updated<I: Into<DateTime>>(self, val: I) -> Self
Builder function that sets the Workflow updated.
The date and time at which the object was updated.
Sourceimpl<Vocab: ActivityVocabulary> Workflow<Vocab>
impl<Vocab: ActivityVocabulary> Workflow<Vocab>
Sourcepub fn inbox(&self) -> Option<&Item>
pub fn inbox(&self) -> Option<&Item>
Gets the Workflow inbox.
A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.
Sourcepub fn set_inbox<I: Into<Item>>(&mut self, val: I)
pub fn set_inbox<I: Into<Item>>(&mut self, val: I)
Sets the Workflow inbox.
A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.
Sourcepub fn unset_inbox(&mut self) -> Option<Item>
pub fn unset_inbox(&mut self) -> Option<Item>
Unsets the Workflow inbox.
A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.
Sourcepub fn with_inbox<I: Into<Item>>(self, val: I) -> Self
pub fn with_inbox<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow inbox.
A reference to an ActivityStreams OrderedCollection comprised of all the messages received by the actor; see 5.2 Inbox.
Sourcepub fn outbox(&self) -> Option<&Item>
pub fn outbox(&self) -> Option<&Item>
Gets the Workflow outbox.
An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.
Sourcepub fn set_outbox<I: Into<Item>>(&mut self, val: I)
pub fn set_outbox<I: Into<Item>>(&mut self, val: I)
Sets the Workflow outbox.
An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.
Sourcepub fn unset_outbox(&mut self) -> Option<Item>
pub fn unset_outbox(&mut self) -> Option<Item>
Unsets the Workflow outbox.
An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.
Sourcepub fn with_outbox<I: Into<Item>>(self, val: I) -> Self
pub fn with_outbox<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow outbox.
An ActivityStreams OrderedCollection comprised of all the messages produced by the actor; see 5.1 Outbox.
Sourcepub fn following(&self) -> Option<&Item>
pub fn following(&self) -> Option<&Item>
Gets the Workflow following.
A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.
Sourcepub fn set_following<I: Into<Item>>(&mut self, val: I)
pub fn set_following<I: Into<Item>>(&mut self, val: I)
Sets the Workflow following.
A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.
Sourcepub fn unset_following(&mut self) -> Option<Item>
pub fn unset_following(&mut self) -> Option<Item>
Unsets the Workflow following.
A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.
Sourcepub fn with_following<I: Into<Item>>(self, val: I) -> Self
pub fn with_following<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow following.
A link to an ActivityStreams collection of the actors that this actor is following; see 5.4 Following Collection.
Sourcepub fn followers(&self) -> Option<&Item>
pub fn followers(&self) -> Option<&Item>
Gets the Workflow followers.
A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.
Sourcepub fn set_followers<I: Into<Item>>(&mut self, val: I)
pub fn set_followers<I: Into<Item>>(&mut self, val: I)
Sets the Workflow followers.
A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.
Sourcepub fn unset_followers(&mut self) -> Option<Item>
pub fn unset_followers(&mut self) -> Option<Item>
Unsets the Workflow followers.
A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.
Sourcepub fn with_followers<I: Into<Item>>(self, val: I) -> Self
pub fn with_followers<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow followers.
A link to an ActivityStreams collection of the actors that follow this actor; see 5.3 Followers Collection.
Sourcepub fn liked(&self) -> Option<&Item>
pub fn liked(&self) -> Option<&Item>
Gets the Workflow liked.
A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.
Sourcepub fn set_liked<I: Into<Item>>(&mut self, val: I)
pub fn set_liked<I: Into<Item>>(&mut self, val: I)
Sets the Workflow liked.
A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.
Sourcepub fn unset_liked(&mut self) -> Option<Item>
pub fn unset_liked(&mut self) -> Option<Item>
Unsets the Workflow liked.
A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.
Sourcepub fn with_liked<I: Into<Item>>(self, val: I) -> Self
pub fn with_liked<I: Into<Item>>(self, val: I) -> Self
Builder function that sets the Workflow liked.
A link to an ActivityStreams collection of objects this actor has liked; see 5.5 Liked Collection.
Sourcepub fn streams(&self) -> Option<&Items>
pub fn streams(&self) -> Option<&Items>
Gets the Workflow streams.
A list of supplementary Collections which may be of interest.
Sourcepub fn set_streams<I: Into<Items>>(&mut self, val: I)
pub fn set_streams<I: Into<Items>>(&mut self, val: I)
Sets the Workflow streams.
A list of supplementary Collections which may be of interest.
Sourcepub fn unset_streams(&mut self) -> Option<Items>
pub fn unset_streams(&mut self) -> Option<Items>
Unsets the Workflow streams.
A list of supplementary Collections which may be of interest.
Sourcepub fn with_streams<I: Into<Items>>(self, val: I) -> Self
pub fn with_streams<I: Into<Items>>(self, val: I) -> Self
Builder function that sets the Workflow streams.
A list of supplementary Collections which may be of interest.
Sourcepub fn preferred_username(&self) -> Option<&Name>
pub fn preferred_username(&self) -> Option<&Name>
Gets the Workflow preferred_username.
A short username which may be used to refer to the actor, with no uniqueness guarantees.
Sourcepub fn set_preferred_username<I: Into<Name>>(&mut self, val: I)
pub fn set_preferred_username<I: Into<Name>>(&mut self, val: I)
Sets the Workflow preferred_username.
A short username which may be used to refer to the actor, with no uniqueness guarantees.
Sourcepub fn unset_preferred_username(&mut self) -> Option<Name>
pub fn unset_preferred_username(&mut self) -> Option<Name>
Unsets the Workflow preferred_username.
A short username which may be used to refer to the actor, with no uniqueness guarantees.
Sourcepub fn with_preferred_username<I: Into<Name>>(self, val: I) -> Self
pub fn with_preferred_username<I: Into<Name>>(self, val: I) -> Self
Builder function that sets the Workflow preferred_username.
A short username which may be used to refer to the actor, with no uniqueness guarantees.
Sourcepub fn endpoints(&self) -> Option<&Endpoints>
pub fn endpoints(&self) -> Option<&Endpoints>
Gets the Workflow endpoints.
A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.
This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.
Sourcepub fn set_endpoints<I: Into<Endpoints>>(&mut self, val: I)
pub fn set_endpoints<I: Into<Endpoints>>(&mut self, val: I)
Sets the Workflow endpoints.
A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.
This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.
Sourcepub fn unset_endpoints(&mut self) -> Option<Endpoints>
pub fn unset_endpoints(&mut self) -> Option<Endpoints>
Unsets the Workflow endpoints.
A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.
This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.
Sourcepub fn with_endpoints<I: Into<Endpoints>>(self, val: I) -> Self
pub fn with_endpoints<I: Into<Endpoints>>(self, val: I) -> Self
Builder function that sets the Workflow endpoints.
A json object which maps additional (typically server/domain-wide) endpoints which may be useful either for this actor or someone referencing this actor.
This mapping may be nested inside the actor document as the value or may be a link to a JSON-LD document with these properties.
Sourcepub fn assertion_method(&self) -> Option<&MultikeyItems>
pub fn assertion_method(&self) -> Option<&MultikeyItems>
Sourcepub fn set_assertion_method<I: Into<MultikeyItems>>(&mut self, val: I)
pub fn set_assertion_method<I: Into<MultikeyItems>>(&mut self, val: I)
Sourcepub fn unset_assertion_method(&mut self) -> Option<MultikeyItems>
pub fn unset_assertion_method(&mut self) -> Option<MultikeyItems>
Sourcepub fn with_assertion_method<I: Into<MultikeyItems>>(self, val: I) -> Self
pub fn with_assertion_method<I: Into<MultikeyItems>>(self, val: I) -> Self
Sourcepub fn public_key(&self) -> Option<&KeyItems>
👎Deprecated since 0.3.0: The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
pub fn public_key(&self) -> Option<&KeyItems>
The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
Gets the Workflow public_key.
Public key used for HTTP Signatures and Linked Data Signatures.
Sourcepub fn set_public_key<I: Into<KeyItems>>(&mut self, val: I)
👎Deprecated since 0.3.0: The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
pub fn set_public_key<I: Into<KeyItems>>(&mut self, val: I)
The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
Sets the Workflow public_key.
Public key used for HTTP Signatures and Linked Data Signatures.
Sourcepub fn unset_public_key(&mut self) -> Option<KeyItems>
👎Deprecated since 0.3.0: The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
pub fn unset_public_key(&mut self) -> Option<KeyItems>
The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
Unsets the Workflow public_key.
Public key used for HTTP Signatures and Linked Data Signatures.
Sourcepub fn with_public_key<I: Into<KeyItems>>(self, val: I) -> Self
👎Deprecated since 0.3.0: The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
pub fn with_public_key<I: Into<KeyItems>>(self, val: I) -> Self
The publicKey vocabulary has been deprecated since Security Vocabulary 2.0. Users should use the assertionMethod field instead, where possible.
Builder function that sets the Workflow public_key.
Public key used for HTTP Signatures and Linked Data Signatures.